==> nextcloud-16.0.1-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/accessibility/l10n/lt_LT.js <==
OC.L10N.register(
    "accessibility",
    {
    "High contrast theme" : "Didelio kontrasto apipavidalinimas",
    "A high contrast theme to ease your navigation. Visual quality will be reduced but clarity will be increased." : "Didelio kontrasto apipavidalinimas, skirtas palengvinti jūsų naršymą. Vaizdinė kokybė bus sumažinta, tačiau aiškumas bus padidintas.",
    "Dark theme (beta)" : "Tamsus apipavidalinimas (beta)",
    "A dark theme to ease your eyes by reducing the overall luminosity and brightness. It is still under development, so please report any issues you may find." : "Tamsus apipavidalinimas, skirtas nuraminti jūsų akis, sumažinantis bendrą šviesingumą ir skaistį. Jis yra vis dar kuriamas, todėl prašome pranešti apie bet kokias randamas klaidas.",
    "Dyslexia font" : "Disleksijos šriftas",
    "OpenDyslexic is a free typeface/font designed to mitigate some of the common reading errors caused by dyslexia." : "OpenDyslexic yra laisvas šriftas, sukurtas sumažinti kai kurias dažniausias disleksijos sukeltas skaitymo klaidas.",
    "Accessibility" : "Prieinamumas",
    "Accessibility options for nextcloud" : "Nextcloud prieinamumo parinktys",
    "Provides multiple accessibilities options to ease your use of Nextcloud" : "Pateikia kelias prieinamumo parinktis, skirtas palengvinti jūsų naudojimąsi Nextcloud",
    "Web Content Accessibility Guidelines" : "Saityno turinio prieinamumo gairės",
    "our issue tracker" : "mūsų klaidų sekiklis",
    "our design team" : "mūsų dizaino komanda",
    "Enable" : "Įjungti"
},
"nplurals=4; plural=(n % 10 == 1 && (n % 100 > 19 || n % 100 < 11) ? 0 : (n % 10 >= 2 && n % 10 <=9) && (n % 100 > 19 || n % 100 < 11) ? 1 : n % 1 != 0 ? 2: 3);");

==> nextcloud-16.0.4-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/accessibility/l10n/lt_LT.js <==
OC.L10N.register(
    "accessibility",
    {
    "High contrast theme" : "Didelio kontrasto apipavidalinimas",
    "A high contrast theme to ease your navigation. Visual quality will be reduced but clarity will be increased." : "Didelio kontrasto apipavidalinimas, skirtas palengvinti jūsų naršymą. Vaizdinė kokybė bus sumažinta, tačiau aiškumas bus padidintas.",
    "Dark theme" : "Tamsus apipavidalinimas",
    "A dark theme to ease your eyes by reducing the overall luminosity and brightness. It is still under development, so please report any issues you may find." : "Tamsus apipavidalinimas, skirtas nuraminti jūsų akis, sumažinantis bendrą šviesingumą ir skaistį. Jis yra vis dar kuriamas, todėl prašome pranešti apie bet kokias randamas klaidas.",
    "Dyslexia font" : "Disleksijos šriftas",
    "OpenDyslexic is a free typeface/font designed to mitigate some of the common reading errors caused by dyslexia." : "OpenDyslexic yra laisvas šriftas, sukurtas sumažinti kai kurias dažniausias disleksijos sukeltas skaitymo klaidas.",
    "Accessibility" : "Prieinamumas",
    "Accessibility options for nextcloud" : "Nextcloud prieinamumo parinktys",
    "Provides multiple accessibilities options to ease your use of Nextcloud" : "Pateikia kelias prieinamumo parinktis, skirtas palengvinti jūsų naudojimąsi Nextcloud",
    "Web Content Accessibility Guidelines" : "Saityno turinio prieinamumo gairės",
    "our issue tracker" : "mūsų klaidų sekiklis",
    "our design team" : "mūsų dizaino komanda",
    "Enable" : "Įjungti",
    "Dark theme (beta)" : "Tamsus apipavidalinimas (beta)",
    "OpenDyslexic is a free typeface/font designed to mitigate some of the common reading errors caused by dyslexia. The typeface was created by Abelardo Gonzalez, who released it through an open-source license." : "OpenDyslexic yra laisvas šriftas, sukurtas sumažinti kai kurias dažniausias disleksijos sukeltas skaitymo klaidas. Šriftą sukūrė Abelardo Gonzalez, kuris šriftą išleido per atvirojo kodo licenciją.",
    "Provides multiple accessibilities options to ease your use of nextcloud" : "Pateikia kelias prieinamumo parinktis, skirtas palengvinti jūsų naudojimąsi Nextcloud",
    "Themes" : "Apipavidalinimai",
    "Fonts" : "Šriftai",
    "enabled" : "įjungta"
},
"nplurals=4; plural=(n % 10 == 1 && (n % 100 > 19 || n % 100 < 11) ? 0 : (n % 10 >= 2 && n % 10 <=9) && (n % 100 > 19 || n % 100 < 11) ? 1 : n % 1 != 0 ? 2: 3);");
